@@ -321,7 +321,7 @@ static const SECTION union { const guint8 data[2496]; const double alignment; vo
   0x6c, 0x2f, 0x00, 0x00, 0x05, 0x00, 0x00, 0x00
 } };
 
-static GStaticResource static_resource = { fish_resource_data.data, sizeof (fish_resource_data.data) };
+static GStaticResource static_resource = { fish_resource_data.data, sizeof (fish_resource_data.data), NULL, NULL, NULL };
 extern GResource *fish_get_resource (void);
 GResource *fish_get_resource (void)
 {
