@@ -614,7 +614,7 @@ static const SECTION union { const guint8 data[4836]; const double alignment; vo
   0x01, 0x00, 0x00, 0x00
 } };
 
-static GStaticResource static_resource = { wncklet_resource_data.data, sizeof (wncklet_resource_data.data) };
+static GStaticResource static_resource = { wncklet_resource_data.data, sizeof (wncklet_resource_data.data), NULL, NULL, NULL };
 extern GResource *wncklet_get_resource (void);
 GResource *wncklet_get_resource (void)
 {
