@@ -34,11 +34,6 @@
 
 G_BEGIN_DECLS
 
-void        wncklet_display_help        (GtkWidget  *widget,
-					 const char *doc_id,
-					 const char *link_id,
-					 const char *icon_name);
-
 WnckScreen *wncklet_get_screen          (GtkWidget *applet);
 	
 void        wncklet_connect_while_alive (gpointer    object,
