@@ -34,7 +34,6 @@
 #include <libpanel-util/panel-error.h>
 #include <libpanel-util/panel-glib.h>
 #include <libpanel-util/panel-launch.h>
-#include <libpanel-util/panel-show.h>
 
 #include "applet.h"
 #include "panel-widget.h"
@@ -847,10 +846,7 @@ panel_menu_button_invoke_menu (PanelMenuButton *button,
 
 	screen = gtk_widget_get_screen (GTK_WIDGET (button));
 
-	if (!strcmp (callback_name, "help")) {
-		panel_show_help (screen, "user-guide", "gospanel-37", NULL);
-
-	} else if (!strcmp (callback_name, "edit")) {
+	if (!strcmp (callback_name, "edit")) {
                 GError *error = NULL;
 
 		panel_launch_desktop_file_with_fallback ("alacarte.desktop",
